<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="41"/>
        <source>License</source>
        <translation>Licentie</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <location filename="../about.cpp" line="52"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <source>Cancel</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>&amp;Sluiten</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="47"/>
        <source>GUI for applying assorted useful tweaks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>launches brightness-systray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>opens with display tab open.  Only valid with Xfce desktop running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Opens theme tab directly.  Valid on Xfce &amp; Fluxbox desktops</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Opens Other tab directly.  Valid on all desktops</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>HoofdScherm</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Software (xrandr) Helderheid</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation>Hardware Backlight</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="33"/>
        <source>MX-Tweak</source>
        <translation>MX-Tweak</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="58"/>
        <source>Display</source>
        <translation>Beeldscherm</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="63"/>
        <source>&amp;Quit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="57"/>
        <location filename="../defaultlook.cpp" line="86"/>
        <location filename="../defaultlook.cpp" line="657"/>
        <location filename="../defaultlook.cpp" line="676"/>
        <location filename="../defaultlook.cpp" line="685"/>
        <location filename="../defaultlook.cpp" line="732"/>
        <location filename="../defaultlook.cpp" line="740"/>
        <location filename="../defaultlook.cpp" line="767"/>
        <location filename="../defaultlook.cpp" line="770"/>
        <source>MX Tweak</source>
        <translation>MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="41"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Het paneel aanpassen&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="51"/>
        <location filename="../defaultlook.ui" line="272"/>
        <source>Panel</source>
        <translation>Paneel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="71"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configureer schermgedrag en snelkoppelingen&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="85"/>
        <source>Window Manager</source>
        <translation>Schermbeheer</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="105"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Pas het uiterlijk van uw desktop aan&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="119"/>
        <source>Appearance</source>
        <translation>Uiterlijk</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="133"/>
        <source>Xfce Settings</source>
        <translation>Xfce Instellingen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="212"/>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="223"/>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="240"/>
        <source>Quit application</source>
        <translation>Verlaat de applicatie</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="243"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="250"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="283"/>
        <source>Display panel horizontally</source>
        <extracomment>panel will be shown in a horizontal configuration</extracomment>
        <translation>Laat paneel horizontaal zien</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="293"/>
        <source>Volume</source>
        <extracomment>volume plugin scale factor</extracomment>
        <translation>Deel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="300"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>affects the docklike plugin</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="307"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Beïnvloedt alle panelen&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="327"/>
        <location filename="../defaultlook.ui" line="1725"/>
        <source>Bottom</source>
        <translation>Onderaan</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="332"/>
        <location filename="../defaultlook.ui" line="1735"/>
        <source>Top</source>
        <translation>Bovenin</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="340"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Tasklist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Takenlijst&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="347"/>
        <source>Display panel vertically</source>
        <extracomment>panel will be shown in a vertical configuration</extracomment>
        <translation>Laat paneel verticaal zien</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="362"/>
        <location filename="../defaultlook.ui" line="1753"/>
        <source>Affects 1st panel</source>
        <extracomment>acts on the first poanel found in Xfce panel xml fle</extracomment>
        <translation>Beïnvloedt 1e paneel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="369"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Panel Plugin Scales&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Panel Plugin Schaling&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="389"/>
        <source>Backup current panel configuration</source>
        <extracomment>backup existing panel configuration</extracomment>
        <translation>Backup huidige paneel configuratie</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="399"/>
        <location filename="../defaultlook.ui" line="459"/>
        <source>Options</source>
        <translation>Opties</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="419"/>
        <source>Power Manager</source>
        <extracomment>power manager plugin scale factor</extracomment>
        <translation>Power Manager</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="426"/>
        <source>Restore backup panel configuration</source>
        <extracomment>restore a panel backup</extracomment>
        <translation>Herstel gebackupte paneel configuratie</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="449"/>
        <source>Set Scales</source>
        <extracomment>set a scale factor</extracomment>
        <translation>Stel Schaling In</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="479"/>
        <location filename="../defaultlook.ui" line="1730"/>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="484"/>
        <location filename="../defaultlook.ui" line="1740"/>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="492"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>affects the window button plugin</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Vensterknoppen&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="513"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Docklike is the modern dock plugin for the panel.  Window Buttons is the classic tasklist without dock features.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Docklike is de moderne dock-plugin voor het paneel.  Window Buttons is de klassieke takenlijst zonder dockfuncties.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="536"/>
        <location filename="../defaultlook.ui" line="630"/>
        <location filename="../defaultlook.ui" line="889"/>
        <location filename="../defaultlook.ui" line="1057"/>
        <location filename="../defaultlook.ui" line="1064"/>
        <location filename="../defaultlook.ui" line="1071"/>
        <location filename="../defaultlook.ui" line="1138"/>
        <location filename="../defaultlook.ui" line="1283"/>
        <location filename="../defaultlook.ui" line="1766"/>
        <location filename="../defaultlook.ui" line="1884"/>
        <location filename="../defaultlook.ui" line="1951"/>
        <source>Apply</source>
        <extracomment>apply changes</extracomment>
        <translation>Toepassen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="556"/>
        <source>Restore default panel</source>
        <extracomment>affects any panel that is curently configured</extracomment>
        <translation>Herstel standaard paneel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="566"/>
        <source>Set Tasklist plugin to:</source>
        <extracomment>change the tasklist plugin</extracomment>
        <translation>Stel Takenlijst plugin in op:</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="580"/>
        <source>Theme</source>
        <translation>Thema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="596"/>
        <source>Theme Options</source>
        <translation>Thema Opties</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="606"/>
        <source>Remove User Theme Set</source>
        <translation>Verwijder Gebruiker Thema Set</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="617"/>
        <source>Preview</source>
        <translation>Voorbeeld</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="656"/>
        <source>Undo</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="666"/>
        <source>Save Current Settings as a Theme Set</source>
        <extracomment>save theme settings as a group</extracomment>
        <translation>Sla Huidige Instellingen op als Thema Set</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="687"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Cursors&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>cursor theme</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="694"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Manager&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>theme a window manager border will get</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Vensterbeheer&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="704"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Application&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>theme an application will get</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Applicatie&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="711"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>icon theme</extracomment>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Iconen&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="728"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Themes&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Thema&apos;s&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="738"/>
        <location filename="../defaultlook.ui" line="756"/>
        <source>Compositor</source>
        <translation>Compositor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="749"/>
        <source>Transparency and shadow options</source>
        <translation>Transparantie- en schaduwopties</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="763"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Bewerkt compton.conf rechtstreeks in tekstverwerker</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="766"/>
        <source>Edit compton.conf</source>
        <translation>Bewerk compton.conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="777"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Instellingen&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="780"/>
        <source>Xfwm Settings</source>
        <translation>Xfwm Instellingen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="791"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Veranderen van de VBlank modus kan wat screen tearing problemen verminderen. Zie Help voor meer informatie.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="794"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="801"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Start compton-conf configuratiegereedschap</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="804"/>
        <source>Compton settings</source>
        <translation>Compton instellingen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="828"/>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="833"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Xfmw (Xfce) Compositor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="838"/>
        <source>Compton </source>
        <translation>Compton</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="847"/>
        <source>auto</source>
        <translation>auto</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="852"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="857"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="862"/>
        <location filename="../defaultlook.ui" line="1396"/>
        <source>off</source>
        <extracomment>setting to 0 turns off screensaver screen blank</extracomment>
        <translation>uit</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="912"/>
        <source>Display</source>
        <translation>Beeldscherm</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="923"/>
        <source>Hardware Backlight</source>
        <extracomment>set the hardware backlight on monitors that have them</extracomment>
        <translation>Hardware Backlight</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="930"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Beeldscherm Instellingen&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="957"/>
        <source>Choose Display for xrandr tweaks</source>
        <extracomment>choose the display that the xrandr tweaks will be acted upon</extracomment>
        <translation>Kies Beeldscherm voor xrandr instellingen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="967"/>
        <source>Resolution</source>
        <translation>Resolutie</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="974"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Opslaan is per beeldscherm&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="977"/>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="984"/>
        <source>Software (xrandr) Brightness</source>
        <extracomment>adjust brightness (not backlight) via software</extracomment>
        <translation>Software (xrandr) Helderheid</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="991"/>
        <location filename="../defaultlook.ui" line="1088"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="998"/>
        <source>GTK scaling</source>
        <extracomment>gtk scale factor</extracomment>
        <translation>GTK schaling</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1018"/>
        <source>xrandr Scaling</source>
        <extracomment>xrandr scale factor</extracomment>
        <translation>xrandr Schaling</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1114"/>
        <source>Config Options</source>
        <translation>Configuratie Opties</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1125"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>Schakel verkorten van lange bestandsnamen op de desktop uit</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1149"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>                   let op: voor slaapstand moet swap &gt;= RAM</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1169"/>
        <source>Enable single-click on desktop</source>
        <translation>Schakel enkel-klik op desktop in</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1176"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Schakel slaapstand in in Afmeldmenu</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1183"/>
        <location filename="../defaultlook.ui" line="1317"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>Herstel Thunar aangepaste rechts-klik acties naar systeem standaard</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1190"/>
        <location filename="../defaultlook.ui" line="1368"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Schakel enkel-klik in Thunar Bestandbeheer in</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1197"/>
        <location filename="../defaultlook.ui" line="1629"/>
        <source>Thunar windows always open in split view</source>
        <translation>Thunar-vensters openen altijd in gesplitste weergave</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1204"/>
        <location filename="../defaultlook.ui" line="1561"/>
        <source>Thunar split view opens horizontal</source>
        <translation>Thunar gesplitste weergave opent horizontaal</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1211"/>
        <source>Show percentages in notifcations when available</source>
        <translation>Toon percentages in meldingen indien beschikbaar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1218"/>
        <source>Enable Desktop Zoom </source>
        <translation>Bureaublad Zoomen Inschakelen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1225"/>
        <location filename="../defaultlook.ui" line="1815"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Laat schermen van alle werkgebieden in paneel zien</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1232"/>
        <source>Show GTK File Dialog action buttons at bottom of dialogs</source>
        <translation>Toon GTK-bestandsdialoog actieknoppen onderaan de dialogen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1239"/>
        <source>( also turns off Client Side Decorations for Xfce applications)</source>
        <translation>(schakelt ook Client Side Decoraties uit voor Xfce-toepassingen)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1252"/>
        <source>Fluxbox</source>
        <translation>Fluxbox </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1264"/>
        <location filename="../defaultlook.ui" line="1604"/>
        <source>On</source>
        <translation>Aan</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1269"/>
        <location filename="../defaultlook.ui" line="1609"/>
        <source>Off</source>
        <translation>Uit</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1290"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Thunar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Thunar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1297"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Toolbar Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Werkbalk Instellingen&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1337"/>
        <source>Toggle icon captions</source>
        <translation>Schakelen bijschriften iconen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1344"/>
        <source>Reset Fluxbox Menu</source>
        <translation>Fluxbox Menu Terugzetten</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1361"/>
        <source>Width</source>
        <translation>Breedte</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1375"/>
        <source>Toggle desktop icons</source>
        <translation>Schakelen bijschriften bureaublad iconen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1382"/>
        <location filename="../defaultlook.ui" line="1406"/>
        <source>Autohide</source>
        <translation>Autoverbergen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1389"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dock Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dock Instellingen&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1480"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Desktop Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Bureaublad Iconen&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1554"/>
        <source>Reset DefaultDock</source>
        <translation>Terugzetten StandaardDock</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1568"/>
        <source>Manage Tint2 Panel</source>
        <translation>Beheer Tint2 Paneel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1579"/>
        <source>Height</source>
        <translation>Hoogte</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1586"/>
        <location filename="../defaultlook.ui" line="1622"/>
        <location filename="../defaultlook.ui" line="1714"/>
        <source>Placement</source>
        <translation>Plaatsing</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1593"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Screensaver&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>screensaver screen blank settings</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1614"/>
        <source>On Hover</source>
        <translation>Tijdens Overzweven</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1636"/>
        <location filename="../defaultlook.ui" line="1829"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Reset Defaults&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Standaarden Terugzetten&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1643"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Add new default menu items, if any, to existing fluxbox menu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Voeg nieuwe standaard menu-onderdelen, voor zover die er zijn, toe aan het bestaande fluxbox menu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1646"/>
        <source>Upgrade existing menu entries</source>
        <translation>Bestaande menu onderdelen opwaarderen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1666"/>
        <source>Show Toolbar</source>
        <translation>Toon Werkbalk</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1683"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation>ALLE mx-fluxbox instellingen terugzetten</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1690"/>
        <source>Idle time (minutes)</source>
        <extracomment>set the time of inactivity  before screensaver screen blank occurs</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1703"/>
        <source>Plasma</source>
        <translation>Plasma</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1782"/>
        <source>Workspace</source>
        <translation>Werkruimte</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1822"/>
        <source>Enable single-click</source>
        <translation>Schakel enkel-klik in</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1836"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation>Herstel KDE/Plasma standaardwaarden</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1846"/>
        <source>Super Key</source>
        <extracomment>referring to the meta or Left Super Key</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1854"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Choose application&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>description of button action to launch file dialog to choose an application</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1867"/>
        <source>Xfce-superkey defaults</source>
        <extracomment>indicates that xfce-superkey will select a command by its default logic</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1874"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Also known as the &amp;quot;windows&amp;quot; key&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1877"/>
        <source>Command to run with Super (Meta) key</source>
        <extracomment>label for the field to enter the command to use with super key</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1907"/>
        <source>Other</source>
        <translation>Overige</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1931"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Herstel Lightdm (login scherm) naar systeem standaard thema</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1938"/>
        <source>Password for administrative tasks:</source>
        <translation>Wachtwoord voor administratieve taken:</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1969"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Maak koppelen van interne schijven door niet-root gebruikers mogelijk</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1976"/>
        <source>Root</source>
        <translation>Root</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1983"/>
        <source>Enable kernel sandbox</source>
        <translation>Schakel kernel sandbox in</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1990"/>
        <source>&amp;User</source>
        <translation>&amp;User</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1997"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;requires reboot&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;vereist opnieuw opstarten&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2000"/>
        <source>Enable Bluetooth Adapters on boot</source>
        <translation>Bluetooth-adapters inschakelen bij opstarten</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2007"/>
        <source>Apt installs additional &quot;recommends&quot; packages as dependencies</source>
        <translation>Apt installeert extra &quot;aanbevolen&quot; pakketten als afhankelijkheden</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2014"/>
        <source>Generate fluxbox All Apps menu after package installation, removal, and updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2021"/>
        <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
        <translation>Gebruik Client Side Decoraties (CSD) op GTK3 applicaties die dat ondersteunen (vereist sessie herstart)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2028"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>Gebruik intel driver in plaats van standaard &quot;modesetting&quot; driver (vereist herstart)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2035"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>NOOT: bestaande /etc/X11/xorg.conf.d/20-intel.conf zal gebackupped worden in de home folder</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2042"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Gebruik tearvrij amdgpu optie</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2049"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>NOOT: bestaande /etc/X11/xorg.conf.d/20-amd.conf zal gebackupped worden in de home folder</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2056"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Gebruik tearvrij radeon driver optie</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="2063"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>NOOT: bestaande /etc/X11/xorg.conf.d/20-radeon.conf zal gebackupped worden in de home folder</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="58"/>
        <source>--display switch only valid for Xfce</source>
        <translation>--display schakel enkel geldig voor Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="656"/>
        <source>About MX Tweak</source>
        <translation>Over MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="658"/>
        <source>Version: </source>
        <translation>Versie:</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="659"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>App voor snelle standaard ui thema veranderingen en fijninstellingen</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="661"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="662"/>
        <source>%1 License</source>
        <translation>%1 Licentie</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="676"/>
        <source>%1 Help</source>
        <translation>%1 Help</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="686"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>Klaar! Firefox kan een herstart vereisen om de veranderingen door te voeren</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="733"/>
        <source>Plese remove special characters</source>
        <translation>Gelieve speciale tekens te verwijderen</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="733"/>
        <source>from file name</source>
        <translation>van bestandsnaam</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="740"/>
        <source>File name already exists.  Choose another name</source>
        <translation>Bestandsnaam bestaat al.  Kies een andere naam</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="768"/>
        <source>File is not a valid tar.xz archive file</source>
        <translation>Bestand is geen geldig tar.xz archiefbestand</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="771"/>
        <source>Archive does not contain a panel config</source>
        <translation>Archief bevat geen paneelconfiguratie</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="946"/>
        <source>Panel settings</source>
        <translation>Paneel instellingen</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="947"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>Uw huidige paneelinstellingen zijn gebackupt in een verborgen folder genaamd .restore in uw home folder (~/.restore/)</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1729"/>
        <source>settings</source>
        <translation>instellingen</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="2069"/>
        <source>Choose a theme set</source>
        <translation>Kies een thema set</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="3967"/>
        <source>Select application to run</source>
        <comment>will show in file dialog when selection an application to run</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Verwijder Gebruiker Thema Set</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Nieuwe Thema Set</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Voer naam in voor nieuwe thema set</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="24"/>
        <source>Window Buttons</source>
        <translation>Vensterknoppen</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Uiterlijk&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Toon knopetiketten</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Toon platte knoppen</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Toon handgreep</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Sorteervolgorde:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Tijdstempel</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Groeptitel en tijdstempel</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Venstertitel</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Groeptitel en venstertitel</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>Geen, sta sleep-en-plak toe</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Gedrag&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Venstergroepering:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Nooit</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Altijd</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Actie bij middelklik:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Niets</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Sluit venster</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Minimaliseer venster</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Herstel geminimaliseerde vensters naar het huidige werkblad</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Teken vensterrand als de muisaanwijzer over een knop zweeft</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Wissel vensters met het muiswieltje</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filteren&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Toon vensters van alle werkbladen</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Toon alleen geminimaliseerde vensters</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Toon vensters van alle monitors</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>Pop-up Scherm</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>Schermen gedurende verplaatsing</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Doorschijnendheid Instellingen&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>Schermdecoraties</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Laat schaduwen onder dock schermen zien</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>Laat schaduwen onder pop-up schermen zien</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>Schermen gedurende maatverandering</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Laat schaduwen onder reguliere schermen zien</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Kenmerk Instellingen&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Laat schermen zien in plaats van iconen wanneer gerold wordt</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Laat volledig scherm overlayschermen rechtstreeks zien</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>Inactieve schermen</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Synchroniseer tekenen naar vertikale blanco</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="23"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Xfwm Compositor Instellingen</translation>
    </message>
</context>
</TS>
